@@ -7,3 +7,7 @@ class unrecaptured_section_1250_gain(Variable):
     label = "Un-recaptured section 1250 gain"
     unit = USD
     definition_period = YEAR
+    reference = dict(
+        title="26 U.S. Code § 1250(a)",
+        href="https://www.law.cornell.edu/uscode/text/26/1250#a",
+    )
